pub struct Orbit {
pub src: CameraFrame,
pub target: DVec3,
pub distance: f64,
pub phi: f64,
pub theta0: f64,
pub total_angle: f64,
}Expand description
An orbit animation rotating the camera around a target.
Fields
src: CameraFrameThe camera state at the start of the orbit.
target: DVec3The orbit target.
distance: f64Distance from the target.
phi: f64Elevation angle kept constant during the orbit.
theta0: f64Initial azimuth angle.
total_angle: f64Total angle to rotate, in radians.